@@ -2,6 +2,9 @@ import datetime
 import logging
 import threading
 
+import aprsd
+from aprsd import utils
+
 LOG = logging.getLogger("APRSD")
 
 
@@ -12,6 +15,8 @@ class APRSDStats:
     config = None
 
     start_time = None
+    _aprsis_server = None
+    _aprsis_keepalive = None
 
     _msgs_tracked = 0
     _msgs_tx = 0
@@ -26,12 +31,16 @@ class APRSDStats:
     _email_tx = 0
     _email_rx = 0
 
+    _mem_current = 0
+    _mem_peak = 0
+
     def __new__(cls, *args, **kwargs):
         if cls._instance is None:
             cls._instance = super().__new__(cls)
             # any initializetion here
             cls._instance.lock = threading.Lock()
             cls._instance.start_time = datetime.datetime.now()
+            cls._instance._aprsis_keepalive = datetime.datetime.now()
         return cls._instance
 
     def __init__(self, config=None):
@@ -41,7 +50,43 @@ class APRSDStats:
     @property
     def uptime(self):
         with self.lock:
-            return str(datetime.datetime.now() - self.start_time)
+            return datetime.datetime.now() - self.start_time
+
+    @property
+    def memory(self):
+        with self.lock:
+            return self._mem_current
+
+    def set_memory(self, memory):
+        with self.lock:
+            self._mem_current = memory
+
+    @property
+    def memory_peak(self):
+        with self.lock:
+            return self._mem_peak
+
+    def set_memory_peak(self, memory):
+        with self.lock:
+            self._mem_peak = memory
+
+    @property
+    def aprsis_server(self):
+        with self.lock:
+            return self._aprsis_server
+
+    def set_aprsis_server(self, server):
+        with self.lock:
+            self._aprsis_server = server
+
+    @property
+    def aprsis_keepalive(self):
+        with self.lock:
+            return self._aprsis_keepalive
+
+    def set_aprsis_keepalive(self):
+        with self.lock:
+            self._aprsis_keepalive = datetime.datetime.now()
 
     @property
     def msgs_tx(self):
@@ -126,7 +171,30 @@ class APRSDStats:
 
     def stats(self):
         now = datetime.datetime.now()
+        if self._email_thread_last_time:
+            last_update = str(now - self._email_thread_last_time)
+        else:
+            last_update = "never"
+
+        if self._aprsis_keepalive:
+            last_aprsis_keepalive = str(now - self._aprsis_keepalive)
+        else:
+            last_aprsis_keepalive = "never"
+
         stats = {
+            "aprsd": {
+                "version": aprsd.__version__,
+                "uptime": utils.strfdelta(self.uptime),
+                "memory_current": self.memory,
+                "memory_current_str": utils.human_size(self.memory),
+                "memory_peak": self.memory_peak,
+                "memory_peak_str": utils.human_size(self.memory_peak),
+            },
+            "aprs-is": {
+                "server": self.aprsis_server,
+                "callsign": self.config["aprs"]["login"],
+                "last_update": last_aprsis_keepalive,
+            },
             "messages": {
                 "tracked": self.msgs_tracked,
                 "sent": self.msgs_tx,
@@ -136,9 +204,10 @@ class APRSDStats:
                 "mic-e recieved": self.msgs_mice_rx,
             },
             "email": {
+                "enabled": self.config["aprsd"]["email"]["enabled"],
                 "sent": self._email_tx,
                 "recieved": self._email_rx,
-                "thread_last_update": str(now - self._email_thread_last_time),
+                "thread_last_update": last_update,
             },
         }
         return stats
